From d718eab351292e3c4d168738f9cd543044c335bc Mon Sep 17 00:00:00 2001
From: Morph <39850852+Morph1984@users.noreply.github.com>
Date: Sun, 5 Mar 2023 20:54:13 -0500
Subject: [PATCH] native_clock: Wait for 10 seconds instead of 30

It was experimentally determined to be sufficient.
---
 src/common/x64/native_clock.cpp | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/common/x64/native_clock.cpp b/src/common/x64/native_clock.cpp
index 3f90343a52..76c66e7eed 100644
--- a/src/common/x64/native_clock.cpp
+++ b/src/common/x64/native_clock.cpp
@@ -72,13 +72,13 @@ NativeClock::NativeClock(u64 emulated_cpu_frequency_, u64 emulated_clock_frequen
                          u64 rtsc_frequency_)
     : WallClock(emulated_cpu_frequency_, emulated_clock_frequency_, true), rtsc_frequency{
                                                                                rtsc_frequency_} {
     // Thread to re-adjust the RDTSC frequency after 30 seconds has elapsed.
     time_sync_thread = std::jthread{[this](std::stop_token token) {
         // Get the current time.
         const auto start_time = Common::RealTimeClock::Now();
         const u64 tsc_start = FencedRDTSC();
-        // Wait for 30 seconds.
-        if (!Common::StoppableTimedWait(token, std::chrono::seconds{30})) {
+        // Wait for 10 seconds.
+        if (!Common::StoppableTimedWait(token, std::chrono::seconds{10})) {
             return;
         }
         const auto end_time = Common::RealTimeClock::Now();
@@ -72,13 +72,13 @@ NativeClock::NativeClock(u64 emulated_cpu_frequency_, u64 emulated_clock_frequen
     : WallClock(emulated_cpu_frequency_, emulated_clock_frequency_, true), rtsc_frequency{
                                                                                rtsc_frequency_} {
-    // Thread to re-adjust the RDTSC frequency after 30 seconds has elapsed.
+    // Thread to re-adjust the RDTSC frequency after 10 seconds has elapsed.
     time_sync_thread = std::jthread{[this](std::stop_token token) {
         // Get the current time.